@@ -2,7 +2,7 @@ use super::*;
 
 impl TailwindBackgroundBrightness {
     #[inline]
-    pub fn parse(rest: &[&str], arbitrary: &str) -> Result<Self> {
+    pub fn parse(rest: &[&str], arbitrary: &TailwindArbitrary) -> Result<Self> {
         Ok(Self { brightness: TailwindBrightness::parse(rest, arbitrary, false)? })
     }
 }
