@@ -3,8 +3,8 @@ use crate::{tw_idempotency, TailwindBuilder};
 #[test]
 fn build_aspect() {
     let builder = TailwindBuilder::default();
-    let out = format!("{:?}", builder.inline("aspect-square"));
-    assert_eq!(out, "{aspect-ratio: 1 / 1;}")
+    let out = builder.inline("aspect-square");
+    assert_eq!(out, "aspect-ratio:1/1;")
 }
 
 #[test]
