@@ -2,8 +2,8 @@ use super::*;
 
 impl TailwindDuration {
     /// https://tailwindcss.com/docs/transition-duration
-    pub fn parse(input: &[&str], arbitrary: &str) -> Result<Self> {
-        debug_assert!(arbitrary.is_empty(), "forbidden arbitrary in duration");
+    pub fn parse(input: &[&str], arbitrary: &TailwindArbitrary) -> Result<Self> {
+        debug_assert!(arbitrary.is_none(), "forbidden arbitrary in duration");
         match input {
             [n] => Ok(Self { ms: parse_usize(n)? }),
             _ => syntax_error!("Unknown duration instructions: {}", input.join("-")),
@@ -13,8 +13,8 @@ impl TailwindDuration {
 
 impl TailwindDelay {
     /// https://tailwindcss.com/docs/transition-delay
-    pub fn parse(input: &[&str], arbitrary: &str) -> Result<Self> {
-        debug_assert!(arbitrary.is_empty(), "forbidden arbitrary in duration");
+    pub fn parse(input: &[&str], arbitrary: &TailwindArbitrary) -> Result<Self> {
+        debug_assert!(arbitrary.is_none(), "forbidden arbitrary in duration");
         match input {
             [n] => Ok(Self { ms: parse_usize(n)? }),
             _ => syntax_error!("Unknown delay instructions: {}", input.join("-")),
